@@ -76,7 +76,6 @@ OC.L10N.register(
     "Cards due tomorrow" : "Tarjetas para mañana",
     "Upcoming cards" : "Tarjetas próximas",
     "Load more" : "Cargar más",
-    "Personal" : "Personal",
     "The card \"%s\" on \"%s\" has reached its due date." : "La tarjeta \"%s\" en \"%s\" ha alacanzado su fecha de entrega",
     "The board \"%s\" has been shared with you by %s." : "El tablero \"%s\" ha sido compartido contigo por %s.",
     "Deck board" : "Tablero de Deck",
@@ -86,6 +85,8 @@ OC.L10N.register(
     "Action needed" : "Acción requerida",
     "Later" : "Después",
     "copy" : "copiar",
+    "To Do" : "Pendiente",
+    "In Progress" : "En proceso",
     "Done" : "Terminado",
     "The file was uploaded" : "El archivo fue cargado",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo cargado excede el valor establecido en la directiva upload_max_filesize en el archivo php.ini",
@@ -101,12 +102,13 @@ OC.L10N.register(
     "Add board" : "Añadir pizarra",
     "Move card" : "Mover tarjeta",
     "Cancel" : "Cancelar",
+    "Drop your files to upload" : "Arrastre sus archivos para cargar",
     "File already exists" : "El archivo ya existe",
     "Do you want to overwrite it?" : "¿Deseas sobre escribirlo?",
-    "Drop your files to upload" : "Arrastre sus archivos para cargar",
     "Add card" : "Agregar tarjeta",
     "Archived cards" : "Tarjetas archivadas",
     "Add list" : "Añadir lista",
+    "List name" : "Nombre de lista",
     "Active filters" : "Filtros activos",
     "Filter by tag" : "Filtrar por etiqueta",
     "Unassigned" : "No asignado",
@@ -125,6 +127,8 @@ OC.L10N.register(
     "Tags" : "Etiquetas",
     "Activity" : "Actividad",
     "Undo" : "Deshacer",
+    "Failed to create share with {displayName}" : "Fallo al crear el recurso compartido denominado {displayName}",
+    "Transfer" : "Transferir",
     "No participants found" : "No se encontraron participantes",
     "(Group)" : "(Grupo)",
     "Can edit" : "Puede editar",
@@ -132,24 +136,22 @@ OC.L10N.register(
     "Can manage" : "Puede gestionar",
     "Owner" : "Dueño",
     "Delete" : "Borrar",
-    "Failed to create share with {displayName}" : "Fallo al crear el recurso compartido denominado {displayName}",
-    "Transfer" : "Transferir",
     "Delete list" : "Eliminar lista",
     "Edit" : "Editar",
     "Members" : "Miembros",
+    "Invalid path selected" : "Ruta seleccionada no válida.",
     "Upload new files" : "Cargar nuevos archivos",
     "Share from Files" : "Compartir desde Archivos",
     "Show in Files" : "Mostrar en Archivos",
     "Download" : "Descargar",
-    "Invalid path selected" : "Ruta seleccionada no válida.",
-    "Attachments" : "Adjuntos",
-    "Comments" : "Comentarios",
     "Modified" : "Modificado",
     "Created" : "Creado",
+    "Attachments" : "Adjuntos",
+    "Comments" : "Comentarios",
     "Save" : "Guardar",
+    "Created:" : "Creado:",
     "Reply" : "Responder",
     "Update" : "Actualizar",
-    "Created:" : "Creado:",
     "Description" : "Descripción",
     "Formatting help" : "Ayuda de formato",
     "Edit description" : "Editar descripción",
@@ -171,6 +173,8 @@ OC.L10N.register(
     "Archived boards" : "Tableros archivados",
     "Shared with you" : "Compartido con usted",
     "Cancel edit" : "Cancelar edición",
+    "No reminder" : "Sin recordatorio",
+    "An error occurred" : "Ha ocurrido un error",
     "Board details" : "Detalles del tablero",
     "Edit board" : "Editar el tablero",
     "Clone board" : "Clonar pizarra",
@@ -178,13 +182,14 @@ OC.L10N.register(
     "Archive board" : "Archivar tablero",
     "No notifications" : "No hay notificaciones",
     "Delete board" : "Borrar tableros",
-    "No reminder" : "Sin recordatorio",
-    "An error occurred" : "Ha ocurrido un error",
+    "Clone cards" : "Clonar tarjetas",
+    "Advanced options" : "Opciones avanzadas",
+    "Clone" : "Clonar",
     "Today" : "Hoy",
     "Tomorrow" : "Mañana",
     "Close" : "Cerrar",
     "Error creating the share" : "Error creando el recurso compartido",
     "Share" : "Compartir",
-    "Searching for users, groups and circles …" : "Buscando usuarios, grupos y círculos …"
+    "Personal" : "Personal"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
