@@ -1,4 +1,5 @@
 <?php
+
 /**
  * SPDX-FileCopyrightText: 2016 Nextcloud GmbH and Nextcloud contributors
  * SPDX-License-Identifier: AGPL-3.0-or-later
@@ -45,7 +46,7 @@ class CardMapper extends QBMapper implements IPermissionMapper {
 		IManager $notificationManager,
 		ICacheFactory $cacheFactory,
 		$databaseType = 'sqlite3',
-		$database4ByteSupport = true
+		$database4ByteSupport = true,
 	) {
 		parent::__construct($db, 'deck_cards', Card::class);
 		$this->labelMapper = $labelMapper;
@@ -402,7 +403,7 @@ class CardMapper extends QBMapper implements IPermissionMapper {
 		if (count($query->getTag())) {
 			foreach ($query->getTag() as $index => $tag) {
 				$qb->innerJoin('c', 'deck_assigned_labels', 'al' . $index, $qb->expr()->eq('c.id', 'al' . $index . '.card_id'));
-				$qb->innerJoin('al'. $index, 'deck_labels', 'l' . $index, $qb->expr()->eq('al' . $index . '.label_id', 'l' . $index . '.id'));
+				$qb->innerJoin('al' . $index, 'deck_labels', 'l' . $index, $qb->expr()->eq('al' . $index . '.label_id', 'l' . $index . '.id'));
 				$qb->andWhere($qb->expr()->iLike('l' . $index . '.title', $qb->createNamedParameter('%' . $this->db->escapeLikeParameter($tag->getValue()) . '%', IQueryBuilder::PARAM_STR)));
 			}
 		}
@@ -410,7 +411,7 @@ class CardMapper extends QBMapper implements IPermissionMapper {
 		foreach ($query->getDuedate() as $duedate) {
 			$dueDateColumn = $this->databaseType === 'sqlite3' ? $qb->createFunction('DATETIME(`c`.`duedate`)') : 'c.duedate';
 			$date = $duedate->getValue();
-			if ($date === "") {
+			if ($date === '') {
 				$qb->andWhere($qb->expr()->isNotNull('c.duedate'));
 				continue;
 			}
@@ -461,7 +462,7 @@ class CardMapper extends QBMapper implements IPermissionMapper {
 			foreach ($query->getAssigned() as $index => $assignment) {
 				$qb->innerJoin('c', 'deck_assigned_users', 'au' . $index, $qb->expr()->eq('c.id', 'au' . $index . '.card_id'));
 				$assignedQueryValue = $assignment->getValue();
-				if ($assignedQueryValue === "") {
+				if ($assignedQueryValue === '') {
 					$qb->andWhere($qb->expr()->isNotNull('au' . $index . '.participant'));
 					continue;
 				}
@@ -589,7 +590,7 @@ class CardMapper extends QBMapper implements IPermissionMapper {
 			}
 			$this->cache->set('findBoardId:' . $id, $result);
 		}
-		return $result !== false ? (int) $result : null;
+		return $result !== false ? (int)$result : null;
 	}
 
 	public function mapOwner(Card &$card) {
